/* gwcc/src/utils.c
 *
 * Copyright (C) 2000, 2001 by Brent D. Ely
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

/*--- Include Libraries ---*/
#include <gtk/gtk.h>
#include <gnome.h>
#include "interface.h"
#include "utils.h"

/*--- Global Variables ---*/
char timestamp_str[80];

   // Global Preference Variables
   extern int  file_save_flag;
   extern int  timestamp_saved_file;
   extern GtkWidget * app1;              // The Main Application Window
   extern GtkWidget * dialog_save_as;    // Dialog  - "Save As..."
   extern GtkWidget * dialog_print;      // Dialog  - "Print"


// ------------------------------------------------------------------------- //
// -------------------->      Timestamp Function     <---------------------- //
// ------------------------------------------------------------------------- //

char *
get_timestamp ()
{
    // Declare local variables
    time_t      rawtime;
    struct tm * timeinfo;

    time(&rawtime);
    timeinfo = localtime(&rawtime);
    sprintf(timestamp_str, "\n--> %s", asctime(timeinfo));

    return timestamp_str;
}


// ------------------------------------------------------------------------- //
// -------------------->    File Saving Function    <----------------------- //
// ------------------------------------------------------------------------- //

int
perform_file_save (char *operation, gpointer user_data)
{
    // Get pointers to window widgets and declare local variables.
    GtkWidget * notebook1         = lookup_widget(app1, "notebook1");
    GtkWidget * text_wsutils      = lookup_widget(app1, "text_wsutils");
    GtkWidget * text_grep         = lookup_widget(app1, "text_grep");
    GtkWidget * text_network      = lookup_widget(app1, "text_network");
    gchar     * save_string       = "";
    gchar     * textbox_text      = "";
    char      * env_homedir       = "";
    char      * fopen_flag        = "";
    char        dialog_str[80]    = "";
    char        file_name[80]     = "";
    char        timestamp_str[80] = "";
    int         notebook_page_num = 0;
    FILE      * save_file_ptr;
    time_t      rawtime;
    struct tm * timeinfo;

    // Decide whether to "Save" or "Save As..."
    if (strcmp(operation, "saveas") == 0) {
        // Read location/filename from "Save As..." Dialog
        save_string = gtk_file_selection_get_filename(GTK_FILE_SELECTION(user_data));
        strncpy(file_name, save_string, strlen(save_string));
        if (strlen(file_name) == 0) {
            return(1);
        }
        gtk_widget_destroy(GTK_WIDGET(user_data));
    }
    else if (strcmp(operation, "temp") == 0) {
        strcat(file_name, "/tmp/gwcc_out.txt");
    }
    else if (strcmp(operation, "home") == 0) {
        env_homedir = getenv("HOME");
        if (env_homedir == NULL) {
            strcpy(env_homedir, "/tmp");
        }
        strcpy(file_name, env_homedir);
        strcat(file_name, "/gwcc_out.txt");
    }

    // Get the number (int) of current notebook page (0...n-1),
    // then pick appropriate textbox to 'Select All' text from.
    notebook_page_num = gtk_notebook_get_current_page((GtkNotebook*)notebook1);
    if (notebook_page_num == 0) {
        textbox_text = gtk_editable_get_chars((GtkEditable*)text_wsutils, 0, -1);
    }
    else if (notebook_page_num == 1) {
        textbox_text = gtk_editable_get_chars((GtkEditable*)text_grep,    0, -1);
    }
    else if (notebook_page_num == 2) {
        textbox_text = gtk_editable_get_chars((GtkEditable*)text_network, 0, -1);
    }

    // PREFS: File Saving Options (Overwrite/Append/Seq)
    if (file_save_flag == 0) {
        fopen_flag = "w";
    }
    else if (file_save_flag == 1) {
        fopen_flag = "a";
    }
    else if (file_save_flag == 2) {
        fopen_flag = "w";
        // BRENT - need to save files sequentially! - 12/2000
        // targeting 0.9.x (05/01)
    }

    // Save file to users choice of location/filename
    if (strlen(textbox_text) > 0) {
        save_file_ptr = fopen(file_name, fopen_flag);
        if (save_file_ptr != NULL) {
            fputs(textbox_text, save_file_ptr);

            // PREFS: Timestamp File (T/F)
            if (timestamp_saved_file) {
                fputs("^^^^^^^^^^^^^^^^^^^^^^^^ \n", save_file_ptr);
                strcpy(timestamp_str, get_timestamp() );
                fputs(timestamp_str, save_file_ptr);
                fputs("======================== \n", save_file_ptr);
            }
        }
        fclose(save_file_ptr);
    }

    // Create a simple GnomeMessageBox that says "File saved..."
/* - commented out for 0.9.5
    if (strcmp(operation, "temp") != 0) {
        sprintf(dialog_str, "Output Saved To: %s.", file_name);
        gnome_dialog_run_and_close(GNOME_DIALOG(gnome_ok_dialog (dialog_str)));
    }
*/

    // We're Done
    return(0);
}

